@@ -90,6 +90,9 @@ class GroupModel(Model):
     fields = {
         "groupname": Converter("cn"),
         "description": Converter("description"),
+        "mailing_list": Converter("fasmailinglist"),
+        "url": Converter("fasurl"),
+        "irc": Converter("fasircchannel", multivalued=True),
     }
 
 
